==> qgis-ltr-devel-3.16.8-3.tar.bz2: apps/qgis-ltr/include/qgsconfig.h <==

// QGSCONFIG.H

#ifndef QGSCONFIG_H
#define QGSCONFIG_H

// Version must be specified according to
// <int>.<int>.<int>-<any text>.
// or else upgrading old project file will not work
// reliably.
// TODO QGIS 4: remove in favor of _QGIS_VERSION
#define VERSION "3.16.8-Hannover"
#define _QGIS_VERSION "3.16.8-Hannover"

//used in vim src/core/qgis.cpp
//The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
//because debuggin it out shows the decimal number 72 which results in incorrect version status.
//As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
//reinstate this more generic approach below at some point though
//#define VERSION_INT 3168
// TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
#define VERSION_INT 31608
#define _QGIS_VERSION_INT 31608
#define ABISYM(x) x ## 31608
//used in main.cpp and anywhere else where the release name is needed
#define RELEASE_NAME "Hannover"

#define QGIS_PLUGIN_SUBDIR "plugins"
#define QGIS_DATA_SUBDIR "."
#define QGIS_LIBEXEC_SUBDIR "."
#define QGIS_LIB_SUBDIR "lib"
#define QGIS_QML_SUBDIR "qml"
#define CMAKE_INSTALL_PREFIX "D:/src/osgeo4w/src/qgis-ltr/osgeo4w/install/apps/qgis-ltr"
#define CMAKE_SOURCE_DIR "D:/src/osgeo4w/src/qgis-ltr/qgis"

#define QGIS_SERVER_MODULE_SUBDIR "server"

#define QSCINTILLA_VERSION_STR "2.11.5"

#if defined( __APPLE__ )
//used by Mac to find system or bundle resources relative to amount of bundling
#define QGIS_MACAPP_BUNDLE 
#endif

#define QT_PLUGINS_DIR "D:/src/osgeo4w/src/qgis-ltr/osgeo4w/osgeo4w/apps/Qt5/plugins"

/* #undef USING_NMAKE */

#define USING_NINJA

#define HAVE_GUI

#define HAVE_POSTGRESQL

#define HAVE_ORACLE

#define SERVER_SKIP_ECW

#define HAVE_SERVER_PYTHON_PLUGINS

#define HAVE_OPENCL

/* #undef ENABLE_MODELTEST */

#define HAVE_3D

#define HAVE_GEOREFERENCER

#define USE_THREAD_LOCAL

/* #undef QGISDEBUG */

/* #undef HAVE_QUICK */

#define HAVE_QT5SERIALPORT

/* #undef HAVE_STATIC_PROVIDERS */

#endif

==> qgis-ltr-devel-3.16.9-1.tar.bz2: apps/qgis-ltr/include/qgsconfig.h <==

// QGSCONFIG.H

#ifndef QGSCONFIG_H
#define QGSCONFIG_H

// Version must be specified according to
// <int>.<int>.<int>-<any text>.
// or else upgrading old project file will not work
// reliably.
// TODO QGIS 4: remove in favor of _QGIS_VERSION
#define VERSION "3.16.9-Hannover"
#define _QGIS_VERSION "3.16.9-Hannover"

//used in vim src/core/qgis.cpp
//The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
//because debuggin it out shows the decimal number 72 which results in incorrect version status.
//As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
//reinstate this more generic approach below at some point though
//#define VERSION_INT 3169
// TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
#define VERSION_INT 31609
#define _QGIS_VERSION_INT 31609
#define ABISYM(x) x ## 31609
//used in main.cpp and anywhere else where the release name is needed
#define RELEASE_NAME "Hannover"

#define QGIS_PLUGIN_SUBDIR "plugins"
#define QGIS_DATA_SUBDIR "."
#define QGIS_LIBEXEC_SUBDIR "."
#define QGIS_LIB_SUBDIR "lib"
#define QGIS_QML_SUBDIR "qml"
#define CMAKE_INSTALL_PREFIX "C:/OSGeo4W64/apps/qgis-ltr"
#define CMAKE_SOURCE_DIR "C:/src/qgis"

#define QGIS_SERVER_MODULE_SUBDIR "server"

#define QSCINTILLA_VERSION_STR "2.10.8"

#if defined( __APPLE__ )
//used by Mac to find system or bundle resources relative to amount of bundling
#define QGIS_MACAPP_BUNDLE 
#endif

#define QT_PLUGINS_DIR "C:/OSGeo4W64/apps/Qt5/plugins"

/* #undef USING_NMAKE */

#define USING_NINJA

#define HAVE_GUI

#define HAVE_POSTGRESQL

#define HAVE_ORACLE

#define SERVER_SKIP_ECW

#define HAVE_SERVER_PYTHON_PLUGINS

#define HAVE_OPENCL

/* #undef ENABLE_MODELTEST */

#define HAVE_3D

#define HAVE_GEOREFERENCER

#define USE_THREAD_LOCAL

/* #undef QGISDEBUG */

/* #undef HAVE_QUICK */

#define HAVE_QT5SERIALPORT

/* #undef HAVE_STATIC_PROVIDERS */

#endif
